@@ -2,20 +2,21 @@ extern crate proc_macro;
 
 use proc_macro::TokenStream;
 use quote::quote;
-use syn::parse::{Parse, ParseStream};
-use syn::{parse, parse2, DeriveInput, Ident, Result};
+use syn::{parse, parse2, DeriveInput, Ident};
+// use syn::parse::{Parse, ParseStream};
+// use syn::Result;
 
-struct ServerStruct {
-    name: Ident,
-}
+// struct ServerStruct {
+//     name: Ident,
+// }
 
-impl Parse for ServerStruct {
-    fn parse(input: ParseStream) -> Result<Self> {
-        Ok(ServerStruct {
-            name: input.parse()?,
-        })
-    }
-}
+// impl Parse for ServerStruct {
+//     fn parse(input: ParseStream) -> Result<Self> {
+//         Ok(ServerStruct {
+//             name: input.parse()?,
+//         })
+//     }
+// }
 
 #[proc_macro_derive(Server, attributes(struct_name))]
 pub fn checkout_server_derive(input: TokenStream) -> TokenStream {
@@ -35,10 +36,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
         .nth(0)
         .expect("struct_name attribute required to derive Server. This should be the name of the struct where ContextProvider is implemented");
 
-    let server_struct: ServerStruct =
-        parse2(server_struct_attribute.tokens.clone()).expect("invalid struct_name");
+    // let server_struct: ServerStruct = parse2(server_struct_attribute.tokens.clone()).expect("invalid struct_name");
+    // let server_struct_name = &server_struct.name;
 
-    let server_struct_name = &server_struct.name;
+    let server_struct_name: Ident =
+        parse2(server_struct_attribute.tokens.clone()).expect("invalid struct_name");
 
     let gen = quote! {
         mod checkout_server {
